---
title: <span class="badge builder"></span> MetricNamesQuery
---
# <span class="badge builder"></span> MetricNamesQuery

## Constructor

```python
MetricNamesQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> azuremonitor.MetricNamesQuery
```

### <span class="badge object-method"></span> metric_namespace

```python
def metric_namespace(metric_namespace: str) -> typing.Self
```

### <span class="badge object-method"></span> raw_query

```python
def raw_query(raw_query: str) -> typing.Self
```

### <span class="badge object-method"></span> resource_group

```python
def resource_group(resource_group: str) -> typing.Self
```

### <span class="badge object-method"></span> resource_name

```python
def resource_name(resource_name: str) -> typing.Self
```

### <span class="badge object-method"></span> subscription

```python
def subscription(subscription: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [MetricNamesQuery](./object-MetricNamesQuery.md)
